bodhi-check-policies — bodhi 3.10.1 documentation

# bodhi-check-policies

## Synopsis

`bodhi-check-policies`

## Description

`bodhi-check-policies` iterates over Updates to check the policies enforced by Greewave for each update.

## Options

`--help`

> Display help text.

`--version`

> Report the Bodhi version and exit.

## Help

If you find bugs in bodhi (or in the man page), please feel free to file a bug report or a pull request:

> https://github.com/fedora-infra/bodhi

Bodhi’s documentation is available online: https://bodhi.fedoraproject.org/docs